@@ -2,7 +2,7 @@ from datetime import datetime
 import sqlalchemy as sa
 
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 
 class Column(sa.Column):
@@ -118,12 +118,12 @@ class ModelConfigurator(object):
         """
         Assigns string column server_default based on column default value
         """
-        if column.default is not None:
-            if (isinstance(column.default.arg, basestring) or
-                    isinstance(column.default.arg, int)):
-                column.server_default = sa.schema.DefaultClause(
-                    str(column.default.arg)
-                )
+        if column.default is not None and (
+            isinstance(column.default.arg, basestring)
+        ):
+            column.server_default = sa.schema.DefaultClause(
+                column.default.arg
+            )
 
     def assign_boolean_defaults(self, column):
         """
